/**
 * The form.
 */
export default class Form {
    /**
     * @constructor
     * @param {FormOptions} options
     */
    constructor(options?: FormOptions);
    /**
     * @public
     * @type {OnEventType}
     */
    public on: OnEventType;
    /**
     * @public
     * @type {String}
     */
    public _id: string;
    /**
     * @private
     * @type {Element}
     */
    private _container;
    /**
     * @private
     * @type {State}
     */
    private _state;
    get: <T>(name: string, strict?: boolean) => T;
    invoke: <T_1>(func: (...args: unknown[]) => T_1, context: unknown, locals: import("didi").LocalsMap) => T_1;
    clear(): void;
    /**
     * Destroy the form, removing it from DOM,
     * if attached.
     */
    destroy(): void;
    /**
     * Open a form schema with the given initial data.
     *
     * @param {Schema} schema
     * @param {Data} [data]
     *
     * @return Promise<{ warnings: Array<any> }>
     */
    importSchema(schema: Schema, data?: Data): Promise<any>;
    /**
     * Submit the form, triggering all field validations.
     *
     * @returns { { data: Data, errors: Errors } }
     */
    submit(): {
        data: Data;
        errors: Errors;
    };
    reset(): void;
    /**
     * @returns {Errors}
     */
    validate(): Errors;
    /**
     * @param {Element|string} parentNode
     */
    attachTo(parentNode: Element | string): void;
    detach(): void;
    /**
     * @private
     *
     * @param {boolean} [emit]
     */
    private _detach;
    /**
     * @param {FormProperty} property
     * @param {any} value
     */
    setProperty(property: FormProperty, value: any): void;
    /**
     * @param {FormEvent} type
     * @param {Function} handler
     */
    off(type: FormEvent, handler: Function): void;
    /**
     * @private
     *
     * @param {FormOptions} options
     * @param {Element} container
     *
     * @returns {Injector}
     */
    private _createInjector;
    /**
     * @private
     */
    private _emit;
    /**
     * @internal
     *
     * @param { { add?: boolean, field: any, remove?: number, value?: any } } update
     */
    _update(update: {
        add?: boolean;
        field: any;
        remove?: number;
        value?: any;
    }): void;
    /**
     * @internal
     */
    _getState(): State;
    /**
     * @internal
     */
    _setState(state: any): void;
    /**
   * @internal
   */
    _getModules(): ({
        __init__: string[];
        expressionLanguage: (string | typeof import("./features/expression-language").FeelExpressionLanguage)[];
        /**
         * @typedef { import('./types').Injector } Injector
         * @typedef { import('./types').Data } Data
         * @typedef { import('./types').Errors } Errors
         * @typedef { import('./types').Schema } Schema
         * @typedef { import('./types').FormProperties } FormProperties
         * @typedef { import('./types').FormProperty } FormProperty
         * @typedef { import('./types').FormEvent } FormEvent
         * @typedef { import('./types').FormOptions } FormOptions
         *
         * @typedef { {
         *   data: Data,
         *   initialData: Data,
         *   errors: Errors,
         *   properties: FormProperties,
         *   schema: Schema
         * } } State
         *
         * @typedef { (type:FormEvent, priority:number, handler:Function) => void } OnEventWithPriority
         * @typedef { (type:FormEvent, handler:Function) => void } OnEventWithOutPriority
         * @typedef { OnEventWithPriority & OnEventWithOutPriority } OnEventType
         */
        templating: (string | typeof import("./features/expression-language").FeelersTemplating)[];
        conditionChecker: (string | typeof import("./features/expression-language").ConditionChecker)[];
    } | {
        __init__: string[];
        markdownRenderer: (string | typeof import("./features/markdown").MarkdownRenderer)[];
    })[];
    /**
     * @internal
     */
    _onEvent(type: any, priority: any, handler: any): void;
    /**
     * @internal
     */
    _getSubmitData(): any;
    /**
     * @internal
     */
    _applyConditions(toFilter: any, data: any): any;
}
export type Injector = import('./types').Injector;
export type Data = import('./types').Data;
export type Errors = import('./types').Errors;
export type Schema = import('./types').Schema;
export type FormProperties = import('./types').FormProperties;
export type FormProperty = import('./types').FormProperty;
export type FormEvent = import('./types').FormEvent;
export type FormOptions = import('./types').FormOptions;
export type State = {
    data: Data;
    initialData: Data;
    errors: Errors;
    properties: FormProperties;
    schema: Schema;
};
export type OnEventWithPriority = (type: FormEvent, priority: number, handler: Function) => void;
export type OnEventWithOutPriority = (type: FormEvent, handler: Function) => void;
export type OnEventType = OnEventWithPriority & OnEventWithOutPriority;
